import { Widget } from '@phosphor/widgets';
import { DaskDashboardLauncher, IDashboardItem } from './dashboard';
import { DaskClusterManager, IClusterModel } from './clusters';
/**
 * A widget for hosting Dask dashboard launchers.
 */
export declare class DaskSidebar extends Widget {
    /**
     * Create a new Dask sidebar.
     */
    constructor(options: DaskSidebar.IOptions);
    /**
     * Get the dashboard launcher associated with the sidebar.
     */
    readonly dashboardLauncher: DaskDashboardLauncher;
    /**
     * Get the cluster manager associated with the sidebar.
     */
    readonly clusterManager: DaskClusterManager;
    private _dashboard;
    private _clusters;
}
/**
 * A namespace for DaskSidebar statics.
 */
export declare namespace DaskSidebar {
    /**
     * Options for the constructor.
     */
    interface IOptions {
        /**
         * A callback to launch a dashboard item.
         */
        launchDashboardItem: (item: IDashboardItem) => void;
        /**
         * A function that attempts to find a link to
         * a dask bokeh server in the current application
         * context.
         */
        linkFinder?: () => Promise<string>;
        /**
         * A function that injects client-connection code for a given cluster.
         */
        clientCodeInjector: (model: IClusterModel) => void;
        /**
         * A function that gets client-connection code for a given cluster.
         */
        clientCodeGetter: (model: IClusterModel) => string;
    }
}
